#clear workspace
rm(list = ls())

#scrub, describe
if (!require("psych")) {
   install.packages("psych", dependencies = TRUE)
   library(psych)
   }
#recode   
if (!require("car")) {
   install.packages("car", dependencies = TRUE)
   library(car)
   }
#heatmap
if (!require("lattice")) {
   install.packages("lattice", dependencies = TRUE)
   library(lattice)
   }

#load data
print("Reading data")
tmpdata <- read.table("20160219_DrawSurvey.csv",header=TRUE,sep=";")

print("Cleaning up")
draw<-subset(tmpdata,select=c(1,3,4,6:16)) 
draw<-scrub(draw,1:14,min=1)
#shorten colnames
colnames(draw) = c("participant","Usage","Expertise","Simple Shapes","Lines","Connectors","Freeform Curves","Symbols","3D Objects","Artwork from Gallery","Layers","Multiple Pages","Import/Export of\nVector Graphics","Import/Export of\nRaster Graphics") 
rm(tmpdata)

#define labels
lUsage <- c("never","rarely","regularly","frequently")
lExpertise <- c("basic","intermediate","advanced","expert")

#summary
print("Summarizing data")
print(describe(draw))

#heatmap
ShowValues <- function(x, y, z, ...) {
                panel.levelplot(x,y,z,...)
                panel.text(x, y, round(z,1))
               }
  
print(levelplot(table(draw$Usage,draw$Expertise),
          xlab="Usage",
		  ylab="Expertise",
		  main="Number of Users",
		  xlim=lUsage,
		  ylim=lExpertise,
		  cuts=3,
		  col.regions= cm.colors(4),
		  panel=ShowValues)
	)	  

#special boxplot	
bpfunc<-function(x){
		  m<-mean(x,na.rm=TRUE)
		  z1<-mean(x[draw$Usage<=2 & draw$Expertise<=2],na.rm=TRUE)
		  z2<-mean(x[draw$Usage<=2 & draw$Expertise>2],na.rm=TRUE)
		  z3<-mean(x[draw$Usage>2 & draw$Expertise<=2],na.rm=TRUE)
		  z4<-mean(x[draw$Usage>2 & draw$Expertise>2],na.rm=TRUE)
		  c(z1,z2,m,z3,z4)}
		  
bp<-boxplot(draw[4:14],plot=FALSE)
bp$stats <- sapply(draw[4:14], bpfunc)
bp$group <- bp$out <- numeric(0) # no outliers when whiskers go to min and max
par(mar=c(3,10,2,2))
par(las=1)
bxp(bp, horizontal=TRUE,,main="Relevance of Features",ylim=c(1,6),axes=FALSE)
box()
axis(side=2,labels=colnames(draw[4:14]),at=c(1:11))
axis(side=1,labels=c("never","","","","","frequently"),at=c(1:6))
